@@ -16,23 +16,34 @@
 #include <fcntl.h>
 #include <dirent.h>
 
-#include "panel-include.h"
+#include <libgnomeui/libgnomeui.h>
+#include <libgnome/libgnome.h>
 
-#include "icon-entry-hack.h"
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+
+#include "panel-util.h"
+
+#include "applet.h"
+#include "panel_config_global.h"
 
 extern GlobalConfig global_config;
 
 extern GSList *applets;
-extern GSList *applets_last;
 
 void
-panel_show_help (const char *path)
+panel_show_help (const char *doc_name, const char *linkid)
 {
-	GnomeHelpMenuEntry help_entry = { "panel" };
-	help_entry.path = (char *)path;
-	gnome_help_display (NULL, &help_entry);
+	gnome_help_display (doc_name,
+			    linkid,
+			    NULL);
+
+	/* FIXME: handle error */
 }
 
+#ifdef FIXME
 static char *
 panel_gnome_help_path (const char *docpath)
 {
@@ -54,7 +65,7 @@ panel_gnome_help_path (const char *docpath)
 
 	g_free (app);
 
-	if ( ! panel_file_exists (fullpath)) {
+	if ( ! g_file_test (fullpath, G_FILE_TEST_EXISTS)) {
 		g_free (fullpath);
 		fullpath = NULL;
 	}
@@ -64,13 +75,15 @@ panel_gnome_help_path (const char *docpath)
 
 	return uri;
 }
+#endif /* FIXME */
 
+#ifdef FIXME
 static char *
 panel_kde_help_path (const char *docpath)
 {
-	GList *li;
+	const GList *li;
 
-	if ( ! panel_file_exists (KDE_DOCDIR))
+	if ( ! g_file_test (KDE_DOCDIR, G_FILE_TEST_EXISTS))
 		return NULL;
 
 	for (li = gnome_i18n_get_language_list ("LC_MESSAGES");
@@ -80,19 +93,22 @@ panel_kde_help_path (const char *docpath)
 						  KDE_DOCDIR,
 						  (char *)li->data,
 						  docpath);
-		if (panel_file_exists (fullpath)) {
+		if (g_file_test (fullpath, G_FILE_TEST_EXISTS)) {
 			char *uri = g_strconcat ("ghelp:", fullpath, NULL);
 			g_free (fullpath);
 			return uri;
 		}
 		g_free (fullpath);
 	}
+
 	return NULL;
 }
+#endif /* FIXME */
 
 char *
 panel_gnome_kde_help_path (const char *docpath)
 {
+#ifdef FIXME
 	char *path;
 
 	if (string_empty (docpath))
@@ -107,6 +123,9 @@ panel_gnome_kde_help_path (const char *docpath)
 		path = panel_kde_help_path (docpath);
 
 	return path;
+#else
+	return NULL;
+#endif
 }
 
 gboolean
@@ -160,9 +179,9 @@ create_text_entry(GtkWidget *table,
 
 	if(func) {
 		gtk_object_set_data (GTK_OBJECT (t), "update_function", func);
-		gtk_signal_connect (GTK_OBJECT (t), "changed",
-				    GTK_SIGNAL_FUNC (updated), 
-				    data);
+		g_signal_connect (G_OBJECT (t), "changed",
+				  G_CALLBACK (updated), 
+				  data);
 	}
 	return entry;
 }
@@ -179,7 +198,6 @@ create_icon_entry(GtkWidget *table,
 {
 	GtkWidget *wlabel;
 	GtkWidget *entry;
-	GtkWidget *t;
 
 	wlabel = gtk_label_new(label);
 	gtk_misc_set_alignment(GTK_MISC(wlabel), 0.0, 0.5);
@@ -190,14 +208,12 @@ create_icon_entry(GtkWidget *table,
 			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 	gtk_widget_show(wlabel);
 
-	entry = gnome_icon_entry_new(history_id,_("Browse"));
-	hack_icon_entry (GNOME_ICON_ENTRY (entry));
+	entry = gnome_icon_entry_new (history_id, _("Browse"));
 
-	gnome_icon_entry_set_pixmap_subdir(GNOME_ICON_ENTRY(entry), subdir);
-	if (text)
-		hack_icon_entry_set_icon(GNOME_ICON_ENTRY(entry),text);
+	gnome_icon_entry_set_pixmap_subdir (GNOME_ICON_ENTRY(entry), subdir);
+	if (text != NULL)
+		gnome_icon_entry_set_filename (GNOME_ICON_ENTRY(entry), text);
 
-	t = gnome_icon_entry_gtk_entry (GNOME_ICON_ENTRY (entry));
 	gtk_table_attach(GTK_TABLE(table), entry,
 			 cols, cole, 1, 2,
 			 GTK_EXPAND | GTK_FILL | GTK_SHRINK,
@@ -205,10 +221,10 @@ create_icon_entry(GtkWidget *table,
 			 GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
 	if(func) {
-		gtk_object_set_data (GTK_OBJECT (t), "update_function", func);
-		gtk_signal_connect (GTK_OBJECT (t), "changed",
-				    GTK_SIGNAL_FUNC (updated), 
-				    data);
+		gtk_object_set_data (GTK_OBJECT (entry), "update_function", func);
+		g_signal_connect (G_OBJECT (entry), "changed",
+				  G_CALLBACK (updated), 
+				  data);
 	}
 
 	return entry;
@@ -538,7 +554,7 @@ remove_directory(const char *dirname, gboolean just_clean)
 		if(strcmp(dent->d_name,".")==0 ||
 		   strcmp(dent->d_name,"..")==0)
 			continue;
-		if(g_file_test(dent->d_name,G_FILE_TEST_ISDIR))
+		if(g_file_test(dent->d_name,G_FILE_TEST_IS_DIR))
 			remove_directory(dent->d_name, FALSE);
 		else
 			unlink(dent->d_name);
@@ -754,8 +770,11 @@ convert_keysym_state_to_string(guint keysym,
 	}
 }
 
+#if FIXME
 static GSList *layered_dialogs = NULL;
+#endif /* FIXME */
 
+#if FIXME
 static void
 panel_dialog_realized (GtkWidget *dialog)
 {
@@ -767,21 +786,25 @@ panel_dialog_realized (GtkWidget *dialog)
 		gnome_win_hints_set_layer (GTK_WIDGET (dialog),
 					   WIN_LAYER_NORMAL);
 }
+#endif /* FIXME */
 
+#if FIXME
 static void
 remove_from_layered (GtkWidget *w)
 {
 	layered_dialogs = g_slist_remove (layered_dialogs, w);
 }
+#endif /* FIXME */
 
 void
 panel_set_dialog_layer (GtkWidget *dialog)
 {
+#if FIXME
 	if (g_slist_find (layered_dialogs, dialog) == NULL) {
 		layered_dialogs = g_slist_prepend (layered_dialogs, dialog);
-		gtk_signal_connect (GTK_OBJECT (dialog), "destroy",
-				    GTK_SIGNAL_FUNC (remove_from_layered),
-				    NULL);
+		g_signal_connect (G_OBJECT (dialog), "destroy",
+				  G_CALLBACK (remove_from_layered),
+				  NULL);
 	}
 
 	if (GTK_WIDGET_REALIZED (dialog) &&
@@ -790,14 +813,16 @@ panel_set_dialog_layer (GtkWidget *dialog)
 		gnome_win_hints_set_layer (GTK_WIDGET (dialog),
 					   WIN_LAYER_ABOVE_DOCK);
 
-	gtk_signal_connect (GTK_OBJECT (dialog), "realize",
-			    GTK_SIGNAL_FUNC (panel_dialog_realized),
-			    NULL);
+	g_signal_connect (G_OBJECT (dialog), "realize",
+			  G_CALLBACK (panel_dialog_realized),
+			  NULL);
+#endif
 }
 
 void
 panel_reset_dialog_layers (void)
 {
+#if FIXME
 	GSList *li;
 
 	for (li = layered_dialogs; li != NULL; li = li->next) {
@@ -814,10 +839,13 @@ panel_reset_dialog_layers (void)
 			gnome_win_hints_set_layer (GTK_WIDGET (dialog),
 						   WIN_LAYER_NORMAL);
 	}
+#endif
 }
 
 GtkWidget *
-panel_error_dialog (const char *format, ...)
+panel_error_dialog (const char *class,
+		    const char *format,
+		    ...)
 {
 	GtkWidget *w;
 	char *s;
@@ -832,11 +860,53 @@ panel_error_dialog (const char *format, ...)
 		va_end (ap);
 	}
 
-	w = gnome_error_dialog (s);
+	w = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_ERROR,
+				    GTK_BUTTONS_OK, s);
+	gtk_window_set_wmclass (GTK_WINDOW (w),
+				class, "Panel");
 	g_free (s);
 
+	gtk_widget_show_all (w);
 	panel_set_dialog_layer (w);
 
+	g_signal_connect_swapped (G_OBJECT (w), "response",
+				   G_CALLBACK (gtk_widget_destroy),
+				   G_OBJECT (w));
+
+	return w;
+}
+
+GtkWidget *
+panel_info_dialog (const char *class,
+		   const char *format,
+		   ...)
+{
+	GtkWidget *w;
+	char *s;
+	va_list ap;
+
+	if (format == NULL) {
+		g_warning ("NULL info dialog");
+		s = g_strdup ("(null)");
+	} else {
+		va_start (ap, format);
+		s = g_strdup_vprintf (format, ap);
+		va_end (ap);
+	}
+
+	w = gtk_message_dialog_new (NULL, 0, GTK_MESSAGE_INFO,
+				    GTK_BUTTONS_OK, s);
+	gtk_window_set_wmclass (GTK_WINDOW (w),
+				class, "Panel");
+	g_free (s);
+
+	gtk_widget_show_all (w);
+	panel_set_dialog_layer (w);
+
+	g_signal_connect_swapped (G_OBJECT (w), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  G_OBJECT (w));
+
 	return w;
 }
 
@@ -853,7 +923,12 @@ string_empty (const char *string)
 gboolean
 is_ext (const char *file, const char *ext)
 {
-	const char *p = strrchr (file, '.');
+	const char *p;
+
+	if (file == NULL)
+		return FALSE;
+
+	p = strrchr (file, '.');
 
 	if (p != NULL &&
 	    strcmp (p, ext) == 0)
@@ -862,65 +937,24 @@ is_ext (const char *file, const char *ext)
 		return FALSE;
 }
 
-/* Do strcasecmp but ignore locale */
-int
-strcasecmp_no_locale (const char *s1, const char *s2)
-{
-	int i;
-
-	/* Error, but don't make them equal then */
-	g_return_val_if_fail (s1 != NULL, G_MAXINT);
-	g_return_val_if_fail (s2 != NULL, G_MININT);
-
-	for (i = 0; s1[i] != '\0' && s2[i] != '\0'; i++) {
-		char a = s1[i];
-		char b = s2[i];
-
-		if (a >= 'A' && a <= 'Z')
-			a -= 'A' - 'a';
-		if (b >= 'A' && b <= 'Z')
-			b -= 'A' - 'a';
-
-		if (a < b)
-			return -1;
-		else if (a > b)
-			return 1;
-	}
-
-	/* find out which string is smaller */
-	if (s2[i] != '\0')
-		return -1; /* s1 is smaller */
-	else if (s1[i] != '\0')
-		return 1; /* s2 is smaller */
-	else
-		return 0; /* equal */
-}
-
-/* stolen from gnome-libs head as they are faster and don't use "stat" */
 gboolean
-panel_file_exists (const char *filename)
+is_ext2 (const char *file,
+	 const char *ext1,
+	 const char *ext2)
 {
-	g_return_val_if_fail (filename != NULL, FALSE);
-	
-	return (access (filename, F_OK) == 0);
-}
+	const char *p;
 
-char *
-panel_is_program_in_path (const char *program)
-{
-	static char **paths = NULL;
-	char **p;
-	
-	if (paths == NULL)
-		paths = g_strsplit(g_getenv("PATH"), ":", -1);
+	if (file == NULL)
+		return FALSE;
 
-	for (p = paths; *p != NULL; p++){
-		char *f = g_strconcat (*p, "/", program, NULL);
-		if (access (f, X_OK) == 0)
-			return f;
-		g_free (f);
-	}
-	return 0;
+	p = strrchr (file, '.');
+
+	if (p != NULL &&
+	    (strcmp (p, ext1) == 0 ||
+	     strcmp (p, ext2) == 0))
+		return TRUE;
+	else
+		return FALSE;
 }
 
 int
@@ -976,3 +1010,245 @@ panel_is_url (const char *url)
 	else
 		return FALSE;
 }
+
+static gboolean
+no_need_to_quote (const char *str)
+{
+	const char *p;
+	
+	/* empty string needs quoting */
+	if (string_empty (str))
+		return TRUE;
+
+	for (p = str; *p != '\0'; p++) {
+		if ((*p >= 'a' && *p <= 'z') ||
+		    (*p >= 'A' && *p <= 'Z') ||
+		    strchr ("_-./", *p) != NULL)
+			continue;
+
+		return FALSE;
+	}
+	return TRUE;
+}
+
+/* Quote string so that it could be on a shell like
+ * quoted line as an argument */
+char *
+panel_quote_string (const char *str)
+{
+	GString *gs;
+	const char *p;
+
+	if (string_empty (str))
+		return g_strdup ("''");
+
+	if (no_need_to_quote (str))
+		return g_strdup (str);
+
+	gs = g_string_new ("'");
+	for (p = str; *p != '\0'; p++) {
+		if (*p == '\'')
+			g_string_append (gs, "'\\''");
+		else
+			g_string_append_c (gs, *p);
+	}
+	g_string_append_c (gs, '\'');
+
+	return g_string_free (gs, FALSE);
+}
+
+void
+panel_push_window_busy (GtkWidget *window)
+{
+	int busy = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (window),
+							 "Panel:WindowBusy"));
+
+	busy ++;
+
+	if (busy == 1) {
+		gtk_widget_set_sensitive (window, FALSE);
+		if (window->window != NULL) {
+			GdkCursor *cursor = gdk_cursor_new (GDK_WATCH);
+			gdk_window_set_cursor (window->window, cursor);
+			gdk_cursor_destroy (cursor);
+			gdk_flush ();
+		}
+	}
+
+	gtk_object_set_data (GTK_OBJECT (window), "Panel:WindowBusy",
+			     GINT_TO_POINTER (busy));
+}
+
+void
+panel_pop_window_busy (GtkWidget *window)
+{
+	int busy = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (window),
+							 "Panel:WindowBusy"));
+	busy --;
+
+	if (busy <= 0) {
+		gtk_widget_set_sensitive (window, TRUE);
+		if (window->window != NULL)
+			gdk_window_set_cursor (window->window, NULL);
+		gtk_object_remove_data (GTK_OBJECT (window),
+					"Panel:WindowBusy");
+	} else {
+		gtk_object_set_data (GTK_OBJECT (window), "Panel:WindowBusy",
+				     GINT_TO_POINTER (busy));
+	}
+}
+
+/*
+ * GnomeVFS reading utils, that look like the libc buffered io stuff
+ */
+struct _ReadBuf {
+	GnomeVFSHandle *handle;
+	char *uri;
+	gboolean eof;
+	char buf[BUFSIZ];
+	gsize size;
+	gsize pos;
+};
+
+int
+readbuf_getc (ReadBuf *rb)
+{
+	if (rb->eof)
+		return EOF;
+
+	if (rb->size == 0 ||
+	    rb->pos == rb->size) {
+		GnomeVFSFileSize bytes_read;
+		/* FIXME: handle other errors */
+		if (gnome_vfs_read (rb->handle,
+				    rb->buf,
+				    BUFSIZ,
+				    &bytes_read) != GNOME_VFS_OK) {
+			rb->eof = TRUE;
+			return EOF;
+		}
+		rb->size = bytes_read;
+		rb->pos = 0;
+
+		if (rb->size == 0) {
+			rb->eof = TRUE;
+			return EOF;
+		}
+	}
+
+	return (int)rb->buf[rb->pos++];
+}
+
+/* Note, does not include the trailing \n */
+char *
+readbuf_gets (char *buf, gsize bufsize, ReadBuf *rb)
+{
+	int c;
+	gsize pos;
+
+	g_return_val_if_fail (rb != NULL, NULL);
+
+	pos = 0;
+	buf[0] = '\0';
+
+	do {
+		c = readbuf_getc (rb);
+		if (c == EOF ||
+		    c == '\n')
+			break;
+		buf[pos++] = c;
+	} while (pos < bufsize-1);
+
+	if (c == EOF &&
+	    pos == 0)
+		return NULL;
+
+	buf[pos++] = '\0';
+
+	return buf;
+}
+
+ReadBuf *
+readbuf_open (const char *uri)
+{
+	GnomeVFSHandle *handle;
+	ReadBuf *rb;
+
+	g_return_val_if_fail (uri != NULL, NULL);
+
+	if (gnome_vfs_open (&handle, uri,
+			    GNOME_VFS_OPEN_READ) != GNOME_VFS_OK)
+		return NULL;
+
+	rb = g_new0 (ReadBuf, 1);
+	rb->handle = handle;
+	rb->uri = g_strdup (uri);
+	rb->eof = FALSE;
+	rb->size = 0;
+	rb->pos = 0;
+
+	return rb;
+}
+
+/* unused for now */
+gboolean
+readbuf_rewind (ReadBuf *rb)
+{
+	if (gnome_vfs_seek (rb->handle,
+			    GNOME_VFS_SEEK_START, 0) == GNOME_VFS_OK)
+		return TRUE;
+
+	gnome_vfs_close (rb->handle);
+	rb->handle = NULL;
+	if (gnome_vfs_open (&rb->handle, rb->uri,
+			    GNOME_VFS_OPEN_READ) == GNOME_VFS_OK)
+		return TRUE;
+
+	return FALSE;
+}
+
+void
+readbuf_close (ReadBuf *rb)
+{
+	if (rb->handle != NULL)
+		gnome_vfs_close (rb->handle);
+	rb->handle = NULL;
+	g_free (rb->uri);
+	rb->uri = NULL;
+
+	g_free (rb);
+}
+
+gboolean
+panel_is_program_in_path (const char *program)
+{
+	char *tmp = g_find_program_in_path (program);
+	if (tmp != NULL) {
+		g_free (tmp);
+		return TRUE;
+	} else {
+		return FALSE;
+	}
+}
+
+char *
+panel_pixmap_discovery (const char *name, gboolean fallback)
+{
+	char *pixmap;
+	pixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+					    name,
+					    TRUE /* only_if_exists */,
+					    NULL /* ret_locations */);
+	if (pixmap == NULL)
+		pixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP, 
+						    name,
+						    TRUE /* only_if_exists */,
+						    NULL /* ret_locations */);
+	/* just as a fallback return something */
+	if (pixmap == NULL && fallback)
+		pixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, 
+						    name,
+						    FALSE /* only_if_exists */,
+						    NULL /* ret_locations */);
+	return pixmap;
+}
