@@ -10,16 +10,36 @@
 #include <gtk/gtk.h>
 
 #include <config.h>
-#include <gnome.h>
-
-#include "panel-include.h"
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <libart_lgpl/art_misc.h>
 #include <libart_lgpl/art_affine.h>
 #include <libart_lgpl/art_filterlevel.h>
+
+#include <libgnome/libgnome.h>
+#include <libgnomeui/libgnomeui.h>
+
+#include "panel_config.h"
+
+#include "aligned-widget.h"
+#include "basep-widget.h"
+#include "border-widget.h"
+#include "drawer-widget.h"
+#include "edge-widget.h"
+#include "floating-widget.h"
+#include "sliding-widget.h"
+#include "panel.h"
 #include "rgb-stuff.h"
 #include "multiscreen-stuff.h"
+
+enum {
+	HELP_BUTTON,
+	CLOSE_BUTTON
+};
+
+/*
+ * FIXME
+ */
 #include "nothing.cP"
 
 static void config_apply (PerPanelConfig *ppc);
@@ -89,7 +109,7 @@ update_config_edge (BasePWidget *panel)
 	    ppc->ppc_origin_change)
 		return;
 
-	g_return_if_fail (IS_BORDER_WIDGET (panel));
+	g_return_if_fail (BORDER_IS_WIDGET (panel));
 
 	if (ppc->edge == BORDER_POS (panel->pos)->edge)
 		return;
@@ -215,9 +235,9 @@ update_config_screen (BasePWidget *w)
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (ppc->screen_spin),
 				   w->screen);
 
-	if (IS_FLOATING_WIDGET (w))
+	if (FLOATING_IS_WIDGET (w))
 		update_config_floating_pos_limits (w);
-	else if (IS_SLIDING_WIDGET (w))
+	else if (SLIDING_IS_WIDGET (w))
 		update_config_offset_limit (w);
 }
 
@@ -290,26 +310,26 @@ update_config_size (GtkWidget *panel)
 
 	p = PANEL_WIDGET(BASEP_WIDGET(panel)->panel);
 	switch(p->sz) {
-	case SIZE_ULTRA_TINY:
+	case PANEL_SIZE_XX_SMALL:
 		i = 0;
 		break;
-	case SIZE_TINY:
+	case PANEL_SIZE_X_SMALL:
 		i = 1;
 		break;
-	case SIZE_SMALL:
+	case PANEL_SIZE_SMALL:
 		i = 2;
 		break;
 	default:
-	case SIZE_STANDARD:
+	case PANEL_SIZE_MEDIUM:
 		i = 3;
 		break;
-	case SIZE_LARGE:
+	case PANEL_SIZE_LARGE:
 		i = 4;
 		break;
-	case SIZE_HUGE:
+	case PANEL_SIZE_X_LARGE:
 		i = 5;
 		break;
-	case SIZE_RIDICULOUS:
+	case PANEL_SIZE_XX_LARGE:
 		i = 6;
 		break;
 	}
@@ -354,13 +374,12 @@ update_config_level (BasePWidget *panel)
 void
 update_config_back (PanelWidget *pw)
 {
-	GtkWidget *t, *item = NULL;
+	GtkWidget *item = NULL;
 	int history = 0;
 	PerPanelConfig *ppc;
-	char *text;
 	
 	g_return_if_fail (pw);
-	g_return_if_fail (IS_PANEL_WIDGET(pw));
+	g_return_if_fail (PANEL_IS_WIDGET(pw));
 	g_return_if_fail (pw->panel_parent);
 
 	ppc = get_config_struct (pw->panel_parent);
@@ -384,21 +403,21 @@ update_config_back (PanelWidget *pw)
 		item = ppc->col;
 		history = 1;
 		break;
-	case PANEL_BACK_PIXMAP:
-		t = gnome_pixmap_entry_gtk_entry
-			(GNOME_PIXMAP_ENTRY (ppc->pix_entry));
+	case PANEL_BACK_PIXMAP: {
+		GtkWidget   *t;
+		const gchar *text;
+
+		t = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (ppc->pix_entry));
+
 		text = gtk_entry_get_text (GTK_ENTRY (t));
-		if (strcmp (sure_string (pw->back_pixmap),
-			    text) != 0) {
+
+		if (strcmp (sure_string (pw->back_pixmap), text))
 			gtk_entry_set_text (GTK_ENTRY (t),
 					    sure_string (pw->back_pixmap));
-		}
+
 		item = ppc->pix;
 		history = 2;
-		break;
-	case PANEL_BACK_TRANSLUCENT:
-		item = ppc->trans;
-		history = 3;
+		}
 		break;
 	}
 
@@ -410,7 +429,7 @@ void
 update_config_anchor (BasePWidget *w)
 {
 	PerPanelConfig *ppc = get_config_struct (GTK_WIDGET (w));
-	g_return_if_fail (IS_SLIDING_WIDGET (w));
+	g_return_if_fail (SLIDING_IS_WIDGET (w));
 
 	if (ppc == NULL ||
 	    ppc->ppc_origin_change)
@@ -425,7 +444,7 @@ update_config_offset (BasePWidget *w)
 {
 	PerPanelConfig *ppc = get_config_struct (GTK_WIDGET (w));
 
-	g_return_if_fail (IS_SLIDING_WIDGET (w));
+	g_return_if_fail (SLIDING_IS_WIDGET (w));
 
 	if (ppc == NULL ||
 	    ppc->ppc_origin_change)
@@ -470,7 +489,7 @@ void
 update_config_align (BasePWidget *w)
 {
 	PerPanelConfig *ppc = get_config_struct (GTK_WIDGET (w));
-	g_return_if_fail (IS_ALIGNED_WIDGET (w));
+	g_return_if_fail (ALIGNED_IS_WIDGET (w));
 
 	if (ppc == NULL ||
 	    ppc->ppc_origin_change)
@@ -504,7 +523,7 @@ config_apply (PerPanelConfig *ppc)
 
 	panel_freeze_changes (PANEL_WIDGET (BASEP_WIDGET (ppc->panel)->panel));
 
-	if(IS_EDGE_WIDGET(ppc->panel))
+	if(EDGE_IS_WIDGET(ppc->panel))
 		border_widget_change_params(BORDER_WIDGET(ppc->panel),
 					    ppc->screen,
 					    ppc->edge,
@@ -521,7 +540,7 @@ config_apply (PerPanelConfig *ppc)
 					    ppc->strech_pixmap_bg,
 					    ppc->rotate_pixmap_bg,
 					    &ppc->back_color);
-	else if(IS_SLIDING_WIDGET(ppc->panel))
+	else if(SLIDING_IS_WIDGET(ppc->panel))
 		sliding_widget_change_params(SLIDING_WIDGET(ppc->panel),
 					     ppc->screen,
 					     ppc->align,
@@ -540,7 +559,7 @@ config_apply (PerPanelConfig *ppc)
 					     ppc->strech_pixmap_bg,
 					     ppc->rotate_pixmap_bg,
 					     &ppc->back_color);
-	else if (IS_ALIGNED_WIDGET (ppc->panel))
+	else if (ALIGNED_IS_WIDGET (ppc->panel))
 		aligned_widget_change_params (ALIGNED_WIDGET (ppc->panel),
 					      ppc->screen,
 					      ppc->align,
@@ -558,7 +577,7 @@ config_apply (PerPanelConfig *ppc)
 					      ppc->strech_pixmap_bg,
 					      ppc->rotate_pixmap_bg,
 					      &ppc->back_color);
-	else if (IS_FLOATING_WIDGET (ppc->panel))
+	else if (FLOATING_IS_WIDGET (ppc->panel))
 		floating_widget_change_params (FLOATING_WIDGET (ppc->panel), 
 					       ppc->screen,
 					       ppc->x,
@@ -577,7 +596,7 @@ config_apply (PerPanelConfig *ppc)
 					       ppc->strech_pixmap_bg,
 					       ppc->rotate_pixmap_bg,
 					       &ppc->back_color);
-	else if(IS_DRAWER_WIDGET(ppc->panel)) {
+	else if(DRAWER_IS_WIDGET(ppc->panel)) {
 	        DrawerPos *dp = DRAWER_POS (BASEP_WIDGET (ppc->panel)->pos);
 		drawer_widget_change_params(DRAWER_WIDGET (ppc->panel),
 					    dp->orient,
@@ -665,9 +684,9 @@ make_hidebuttons_widget (PerPanelConfig *ppc)
 	gtk_object_set_user_data(GTK_OBJECT(button), ppc);
 	if (ppc->mode == BASEP_AUTO_HIDE)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (basep_set_auto_hide), 
-			    NULL);
+	g_signal_connect (G_OBJECT (button), "toggled", 
+			  G_CALLBACK (basep_set_auto_hide), 
+			  NULL);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,0);
 
 	/* Hidebuttons enable */
@@ -676,25 +695,25 @@ make_hidebuttons_widget (PerPanelConfig *ppc)
 	gtk_object_set_user_data(GTK_OBJECT(button), ppc);
 	if (ppc->hidebuttons)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (set_toggle),
-			    &ppc->hidebuttons);
+	g_signal_connect (G_OBJECT (button), "toggled", 
+			  G_CALLBACK (set_toggle),
+			  &ppc->hidebuttons);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,0);
 
 	/* Arrow enable */
 	button = gtk_check_button_new_with_label (_("Show arrows on hide button"));
 	ppc->hidebutton_pixmaps_button = button;
-	gtk_signal_connect (GTK_OBJECT (w), "toggled", 
-			    GTK_SIGNAL_FUNC (set_sensitive_toggle),
-			    button);
+	g_signal_connect (G_OBJECT (w), "toggled", 
+			  G_CALLBACK (set_sensitive_toggle),
+			  button);
 	if (!ppc->hidebuttons)
 		gtk_widget_set_sensitive(button,FALSE);
 	gtk_object_set_user_data(GTK_OBJECT(button), ppc);
 	if (ppc->hidebutton_pixmaps)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (set_toggle),
-			    &ppc->hidebutton_pixmaps);
+	g_signal_connect (G_OBJECT (button), "toggled", 
+			  G_CALLBACK (set_toggle),
+			  &ppc->hidebutton_pixmaps);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,0);	
 
 	return frame;
@@ -735,9 +754,9 @@ make_misc_widget (PerPanelConfig *ppc, gboolean avoiding)
 	gtk_object_set_user_data(GTK_OBJECT(button), ppc);
 	if (ppc->avoid_on_maximize)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled", 
-			    GTK_SIGNAL_FUNC (basep_set_avoid), 
-			    NULL);
+	g_signal_connect (G_OBJECT (button), "toggled", 
+			  G_CALLBACK (basep_set_avoid), 
+			  NULL);
 	gtk_box_pack_start (GTK_BOX (box), button, TRUE, TRUE,0);
 
 	if (multiscreen_screens () > 1) {
@@ -755,8 +774,8 @@ make_misc_widget (PerPanelConfig *ppc, gboolean avoiding)
 		gtk_widget_set_usize (GTK_WIDGET (button), 65, 0);
 		gtk_object_set_user_data (GTK_OBJECT (button), ppc);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), ppc->screen);
-		gtk_signal_connect (GTK_OBJECT (button), "changed",
-				    GTK_SIGNAL_FUNC (screen_set), NULL);
+		g_signal_connect (G_OBJECT (button), "changed",
+				  G_CALLBACK (screen_set), NULL);
 		gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 	}
 
@@ -828,12 +847,12 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 				  1 + align, 2 + align,
 				  GTK_FILL,
 				  GTK_EXPAND | GTK_FILL, 0, 0);
-		gtk_signal_connect (GTK_OBJECT (w), "toggled",
-				    GTK_SIGNAL_FUNC (border_set_edge),
-				    GINT_TO_POINTER (BORDER_LEFT));
-		gtk_signal_connect (GTK_OBJECT (w), "toggled",
-				    GTK_SIGNAL_FUNC (border_set_align),
-				    GINT_TO_POINTER (align));
+		g_signal_connect (G_OBJECT (w), "toggled",
+				  G_CALLBACK (border_set_edge),
+				  GINT_TO_POINTER (BORDER_LEFT));
+		g_signal_connect (G_OBJECT (w), "toggled",
+				  G_CALLBACK (border_set_align),
+				  GINT_TO_POINTER (align));
 	}
 	
 
@@ -849,12 +868,12 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 				  1 + align, 2 + align, 0, 1,
 				  GTK_EXPAND | GTK_FILL,
 				  0, 0, 0);
-		gtk_signal_connect (GTK_OBJECT (w), "toggled",
-				    GTK_SIGNAL_FUNC (border_set_edge),
-				    GINT_TO_POINTER (BORDER_TOP));
-		gtk_signal_connect (GTK_OBJECT (w), "toggled",
-				    GTK_SIGNAL_FUNC (border_set_align),
-				    GINT_TO_POINTER (align));
+		g_signal_connect (G_OBJECT (w), "toggled",
+				  G_CALLBACK (border_set_edge),
+				  GINT_TO_POINTER (BORDER_TOP));
+		g_signal_connect (G_OBJECT (w), "toggled",
+				  G_CALLBACK (border_set_align),
+				  GINT_TO_POINTER (align));
 	}
 
 
@@ -871,12 +890,12 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 				  1 + align, 2 + align,
 				  GTK_FILL,
 				  GTK_FILL | GTK_EXPAND, 0, 0);
-		gtk_signal_connect (GTK_OBJECT (w), "toggled",
-				    GTK_SIGNAL_FUNC (border_set_edge),
-				    GINT_TO_POINTER (BORDER_RIGHT));
-		gtk_signal_connect (GTK_OBJECT (w), "toggled",
-				    GTK_SIGNAL_FUNC (border_set_align),
-				    GINT_TO_POINTER (align));
+		g_signal_connect (G_OBJECT (w), "toggled",
+				  G_CALLBACK (border_set_edge),
+				  GINT_TO_POINTER (BORDER_RIGHT));
+		g_signal_connect (G_OBJECT (w), "toggled",
+				  G_CALLBACK (border_set_align),
+				  GINT_TO_POINTER (align));
 	}
 
 
@@ -893,12 +912,12 @@ make_position_widget (PerPanelConfig *ppc, int aligns)
 				  1 + aligns, 2 + aligns,
 				  GTK_EXPAND | GTK_FILL,
 				  0, 0, 0);
-		gtk_signal_connect (GTK_OBJECT (w), "toggled",
-				    GTK_SIGNAL_FUNC (border_set_edge),
-				    GINT_TO_POINTER (BORDER_BOTTOM));
-		gtk_signal_connect (GTK_OBJECT (w), "toggled",
-				    GTK_SIGNAL_FUNC (border_set_align),
-				    GINT_TO_POINTER (align));
+		g_signal_connect (G_OBJECT (w), "toggled",
+				  G_CALLBACK (border_set_edge),
+				  GINT_TO_POINTER (BORDER_BOTTOM));
+		g_signal_connect (G_OBJECT (w), "toggled",
+				  G_CALLBACK (border_set_align),
+				  GINT_TO_POINTER (align));
 	}
 
 	update_position_toggles (ppc);
@@ -1057,9 +1076,9 @@ floating_notebook_page (PerPanelConfig *ppc)
 	if(ppc->orient == PANEL_HORIZONTAL)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_object_set_user_data (GTK_OBJECT (button), ppc);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			    GTK_SIGNAL_FUNC (floating_set_orient),
-			    GINT_TO_POINTER (PANEL_HORIZONTAL));
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (floating_set_orient),
+			  GINT_TO_POINTER (PANEL_HORIZONTAL));
 	gtk_box_pack_start (GTK_BOX (orientbox), button, FALSE, FALSE, 0);
 
 	ppc->v_orient = button = 
@@ -1069,9 +1088,9 @@ floating_notebook_page (PerPanelConfig *ppc)
 	if(ppc->orient == PANEL_VERTICAL)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_object_set_user_data (GTK_OBJECT (button), ppc);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			    GTK_SIGNAL_FUNC (floating_set_orient),
-			    GINT_TO_POINTER (PANEL_VERTICAL));
+	g_signal_connect (G_OBJECT (button), "toggled",
+			  G_CALLBACK (floating_set_orient),
+			  GINT_TO_POINTER (PANEL_VERTICAL));
 	gtk_box_pack_start (GTK_BOX (orientbox), button, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new (FALSE, 0);
@@ -1086,9 +1105,9 @@ floating_notebook_page (PerPanelConfig *ppc)
 	gtk_widget_set_usize (GTK_WIDGET (button), 65, 0);
 	gtk_object_set_user_data (GTK_OBJECT (button), ppc);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), ppc->x);
-	gtk_signal_connect (GTK_OBJECT (button), "changed",
-			    GTK_SIGNAL_FUNC (floating_set_xy),
-			    &ppc->x);
+	g_signal_connect (G_OBJECT (button), "changed",
+			  G_CALLBACK (floating_set_xy),
+			  &ppc->x);
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
 	label = gtk_label_new (_("Y"));
@@ -1100,9 +1119,9 @@ floating_notebook_page (PerPanelConfig *ppc)
 	gtk_widget_set_usize (GTK_WIDGET (button), 65, 0);
 	gtk_object_set_user_data (GTK_OBJECT (button), ppc);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), ppc->y);
-	gtk_signal_connect (GTK_OBJECT (button), "changed",
-			    GTK_SIGNAL_FUNC (floating_set_xy),
-			    &ppc->y);
+	g_signal_connect (G_OBJECT (button), "changed",
+			  G_CALLBACK (floating_set_xy),
+			  &ppc->y);
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
 	w = make_level_widget (ppc);
@@ -1182,8 +1201,8 @@ sliding_notebook_page (PerPanelConfig *ppc)
 		gtk_spin_button_new (adj, 1, 0);
 	gtk_widget_set_usize (button, 100, 0);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (button), ppc->offset);
-	gtk_signal_connect (GTK_OBJECT (button), "changed",
-			    GTK_SIGNAL_FUNC (sliding_set_offset), ppc);
+	g_signal_connect (G_OBJECT (button), "changed",
+			  G_CALLBACK (sliding_set_offset), ppc);
 	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 
 	w = make_level_widget (ppc);
@@ -1215,12 +1234,14 @@ size_set_size (GtkWidget *widget, gpointer data)
 
 /* XXX: until this is fixed in GTK+ */
 static void
-activate_proper_item (GtkMenu *menu)
+activate_proper_item (GtkMenuShell *menu)
 {
+#ifdef FIXME
 	GtkWidget *active;
-	active = gtk_menu_get_active (menu);
+	active = gtk_menu_shell_get_active (menu);
 	if (active != NULL)
 		gtk_menu_item_activate (GTK_MENU_ITEM (active));
+#endif
 }
 
 GtkWidget *
@@ -1246,65 +1267,65 @@ make_size_widget (PerPanelConfig *ppc)
 
 	
 	menu = gtk_menu_new ();
-	gtk_signal_connect (GTK_OBJECT (menu), "deactivate", 
-			    GTK_SIGNAL_FUNC (activate_proper_item), 
-			    NULL);
+	g_signal_connect (G_OBJECT (menu), "deactivate", 
+			  G_CALLBACK (activate_proper_item), 
+			  NULL);
 
-	menuitem = gtk_menu_item_new_with_label (_("Ultra Tiny (12 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("XX Small Tiny (12 pixels)"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (size_set_size),
-			    GINT_TO_POINTER (SIZE_ULTRA_TINY));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (size_set_size),
+			  GINT_TO_POINTER (PANEL_SIZE_XX_SMALL));
 
-	menuitem = gtk_menu_item_new_with_label (_("Tiny (24 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("X Small (24 pixels)"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (size_set_size),
-			    GINT_TO_POINTER (SIZE_TINY));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (size_set_size),
+			  GINT_TO_POINTER (PANEL_SIZE_X_SMALL));
 	
 	menuitem = gtk_menu_item_new_with_label (_("Small (36 pixels)"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (size_set_size),
-			    GINT_TO_POINTER (SIZE_SMALL));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (size_set_size),
+			  GINT_TO_POINTER (PANEL_SIZE_SMALL));
 	
-	menuitem = gtk_menu_item_new_with_label (_("Standard (48 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("Medium (48 pixels)"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (size_set_size),
-			    GINT_TO_POINTER (SIZE_STANDARD));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (size_set_size),
+			  GINT_TO_POINTER (PANEL_SIZE_MEDIUM));
 
 	menuitem = gtk_menu_item_new_with_label (_("Large (64 pixels)"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (size_set_size),
-			    GINT_TO_POINTER (SIZE_LARGE));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (size_set_size),
+			  GINT_TO_POINTER (PANEL_SIZE_LARGE));
 
-	menuitem = gtk_menu_item_new_with_label (_("Huge (80 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("X Large (80 pixels)"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (size_set_size),
-			    GINT_TO_POINTER (SIZE_HUGE));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (size_set_size),
+			  GINT_TO_POINTER (PANEL_SIZE_X_LARGE));
 
-	menuitem = gtk_menu_item_new_with_label (_("Ridiculous (128 pixels)"));
+	menuitem = gtk_menu_item_new_with_label (_("XX Large (128 pixels)"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (size_set_size),
-			    GINT_TO_POINTER (SIZE_RIDICULOUS));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (size_set_size),
+			  GINT_TO_POINTER (PANEL_SIZE_XX_LARGE));
 
 	ppc->size_menu = gtk_option_menu_new ();
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (ppc->size_menu), menu);
@@ -1321,26 +1342,26 @@ make_size_widget (PerPanelConfig *ppc)
 	gtk_box_pack_start (GTK_BOX (vbox), w, FALSE, FALSE, 0);
 
 	switch(ppc->sz) {
-	case SIZE_ULTRA_TINY:
+	case PANEL_SIZE_XX_SMALL:
 		i = 0;
 		break;
-	case SIZE_TINY:
+	case PANEL_SIZE_X_SMALL:
 		i = 1;
 		break;
-	case SIZE_SMALL:
+	case PANEL_SIZE_SMALL:
 		i = 2;
 		break;
 	default:
-	case SIZE_STANDARD:
+	case PANEL_SIZE_MEDIUM:
 		i = 3;
 		break;
-	case SIZE_LARGE:
+	case PANEL_SIZE_LARGE:
 		i = 4;
 		break;
-	case SIZE_HUGE:
+	case PANEL_SIZE_X_LARGE:
 		i = 5;
 		break;
-	case SIZE_RIDICULOUS:
+	case PANEL_SIZE_XX_LARGE:
 		i = 6;
 		break;
 	}
@@ -1381,41 +1402,41 @@ make_level_widget (PerPanelConfig *ppc)
 			    FALSE, FALSE, 0);
 
 	menu = gtk_menu_new ();
-	gtk_signal_connect (GTK_OBJECT (menu), "deactivate", 
-			    GTK_SIGNAL_FUNC (activate_proper_item), 
-			    NULL);
+	g_signal_connect (G_OBJECT (menu), "deactivate", 
+			  G_CALLBACK (activate_proper_item), 
+			  NULL);
 
 	menuitem = gtk_menu_item_new_with_label (_("Default (from global preferences)"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (level_set_level),
-			    GINT_TO_POINTER (BASEP_LEVEL_DEFAULT));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (level_set_level),
+			  GINT_TO_POINTER (BASEP_LEVEL_DEFAULT));
 
 	menuitem = gtk_menu_item_new_with_label (_("Above other windows"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (level_set_level),
-			    GINT_TO_POINTER (BASEP_LEVEL_ABOVE));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (level_set_level),
+			  GINT_TO_POINTER (BASEP_LEVEL_ABOVE));
 
 	menuitem = gtk_menu_item_new_with_label (_("Normal"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (level_set_level),
-			    GINT_TO_POINTER (BASEP_LEVEL_NORMAL));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (level_set_level),
+			  GINT_TO_POINTER (BASEP_LEVEL_NORMAL));
 
 	menuitem = gtk_menu_item_new_with_label (_("Below other windows"));
 	gtk_widget_show(menuitem);
-	gtk_menu_append (GTK_MENU (menu), menuitem);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	gtk_object_set_user_data (GTK_OBJECT (menuitem), ppc);
-	gtk_signal_connect (GTK_OBJECT (menuitem), "activate",
-			    GTK_SIGNAL_FUNC (level_set_level),
-			    GINT_TO_POINTER (BASEP_LEVEL_BELOW));
+	g_signal_connect (G_OBJECT (menuitem), "activate",
+			  G_CALLBACK (level_set_level),
+			  GINT_TO_POINTER (BASEP_LEVEL_BELOW));
 
 	ppc->level_menu = gtk_option_menu_new ();
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (ppc->level_menu), menu);
@@ -1452,7 +1473,8 @@ value_changed (GtkWidget *w, gpointer data)
 	PerPanelConfig *ppc = data;
 
 	g_free(ppc->back_pixmap);
-	ppc->back_pixmap = gnome_pixmap_entry_get_filename(GNOME_PIXMAP_ENTRY(ppc->pix_entry));
+	ppc->back_pixmap = gnome_pixmap_entry_get_filename (
+				GNOME_PIXMAP_ENTRY (ppc->pix_entry));
 
 	panel_config_register_changes (ppc);
 }
@@ -1515,9 +1537,6 @@ set_back (GtkWidget *widget, gpointer data)
 	} else if (back_type == PANEL_BACK_COLOR) {
 		gtk_widget_set_sensitive (pixf, FALSE);
 		gtk_widget_set_sensitive (colf, TRUE);
-	} else if (back_type == PANEL_BACK_TRANSLUCENT) {
-		gtk_widget_set_sensitive (pixf, FALSE);
-		gtk_widget_set_sensitive (colf, FALSE);
 	} else  {
 		gtk_widget_set_sensitive (pixf, TRUE);
 		gtk_widget_set_sensitive (colf, FALSE);
@@ -1531,6 +1550,7 @@ set_back (GtkWidget *widget, gpointer data)
 static void
 color_picker_clicked_signal (GtkWidget *widget, gpointer data)
 {
+#ifdef FIXME
 	GtkWidget *toplevel;
 	GnomeColorPicker *cp;
 
@@ -1547,6 +1567,7 @@ color_picker_clicked_signal (GtkWidget *widget, gpointer data)
 
 	gtk_window_set_transient_for (GTK_WINDOW (cp->cs_dialog),
 				      GTK_WINDOW (toplevel));
+#endif
 }
 
 static GtkWidget *
@@ -1555,7 +1576,6 @@ background_page (PerPanelConfig *ppc)
 	GtkWidget *box, *f, *t;
 	GtkWidget *vbox, *noscale, *fit, *strech;
 	GtkWidget *w, *m;
-	GtkWidget *spinbutton;
 
 	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_container_set_border_width(GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
@@ -1568,25 +1588,21 @@ background_page (PerPanelConfig *ppc)
 
 	/*background type option menu*/
 	m = gtk_menu_new ();
-	gtk_signal_connect (GTK_OBJECT (m), "deactivate", 
-			    GTK_SIGNAL_FUNC (activate_proper_item), 
-			    NULL);
+	g_signal_connect (G_OBJECT (m), "deactivate", 
+			  G_CALLBACK (activate_proper_item), 
+			  NULL);
 	ppc->non = gtk_menu_item_new_with_label (_("Standard"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->non),ppc);
 	gtk_widget_show (ppc->non);
-	gtk_menu_append (GTK_MENU (m), ppc->non);
+	gtk_menu_shell_append (GTK_MENU_SHELL (m), ppc->non);
 	ppc->col = gtk_menu_item_new_with_label (_("Color"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->col),ppc);
 	gtk_widget_show (ppc->col);
-	gtk_menu_append (GTK_MENU (m), ppc->col);
+	gtk_menu_shell_append (GTK_MENU_SHELL (m), ppc->col);
 	ppc->pix = gtk_menu_item_new_with_label (_("Pixmap"));
 	gtk_object_set_user_data(GTK_OBJECT(ppc->pix),ppc);
 	gtk_widget_show (ppc->pix);
-	gtk_menu_append (GTK_MENU (m), ppc->pix);
-	ppc->trans = gtk_menu_item_new_with_label (_("Translucent"));
-	gtk_object_set_user_data(GTK_OBJECT(ppc->trans),ppc);
-	gtk_widget_show (ppc->trans);
-	gtk_menu_append (GTK_MENU (m), ppc->trans);
+	gtk_menu_shell_append (GTK_MENU_SHELL (m), ppc->pix);
 
 	ppc->back_om = gtk_option_menu_new ();
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (ppc->back_om), m);
@@ -1596,7 +1612,6 @@ background_page (PerPanelConfig *ppc)
 	/*color frame*/
 	f = gtk_frame_new (_("Color"));
 	gtk_widget_set_sensitive (f, ppc->back_type == PANEL_BACK_COLOR);
-	gtk_object_set_data(GTK_OBJECT(ppc->trans),"col",f);
 	gtk_object_set_data(GTK_OBJECT(ppc->pix),"col",f);
 	gtk_object_set_data(GTK_OBJECT(ppc->col),"col",f);
 	gtk_object_set_data(GTK_OBJECT(ppc->non),"col",f);
@@ -1613,13 +1628,13 @@ background_page (PerPanelConfig *ppc)
 	ppc->backsel = gnome_color_picker_new();
 	/* This will make sure the selection dialog is set as a transient for
 	 * the config dialog */
-	gtk_signal_connect_after (GTK_OBJECT (ppc->backsel),
-				  "clicked",
-				  GTK_SIGNAL_FUNC (color_picker_clicked_signal),
-				  NULL);
+	g_signal_connect_after (G_OBJECT (ppc->backsel),
+				"clicked",
+				G_CALLBACK (color_picker_clicked_signal),
+				NULL);
 
-	gtk_signal_connect(GTK_OBJECT(ppc->backsel),"color_set",
-			   GTK_SIGNAL_FUNC(color_set_cb), ppc);
+	g_signal_connect (G_OBJECT(ppc->backsel),"color_set",
+			  G_CALLBACK(color_set_cb), ppc);
         gnome_color_picker_set_i16(GNOME_COLOR_PICKER(ppc->backsel),
 				   ppc->back_color.red,
 				   ppc->back_color.green,
@@ -1631,7 +1646,6 @@ background_page (PerPanelConfig *ppc)
 	/*image frame*/
 	f = gtk_frame_new (_("Image"));
 	gtk_widget_set_sensitive (f, ppc->back_type == PANEL_BACK_PIXMAP);
-	gtk_object_set_data(GTK_OBJECT(ppc->trans),"pix",f);
 	gtk_object_set_data(GTK_OBJECT(ppc->pix),"pix",f);
 	gtk_object_set_data(GTK_OBJECT(ppc->col),"pix",f);
 	gtk_object_set_data(GTK_OBJECT(ppc->non),"pix",f);
@@ -1643,15 +1657,15 @@ background_page (PerPanelConfig *ppc)
 	gtk_container_add (GTK_CONTAINER (f), box);
 
 	ppc->pix_entry = gnome_pixmap_entry_new ("pixmap", _("Browse"), TRUE);
-	if(gdk_screen_height()<600)
+	if (gdk_screen_height () < 600)
 		gnome_pixmap_entry_set_preview_size (GNOME_PIXMAP_ENTRY (ppc->pix_entry),
 						     0,50);
-	t = gnome_pixmap_entry_gtk_entry (GNOME_PIXMAP_ENTRY (ppc->pix_entry));
+	t = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (ppc->pix_entry));
 	gtk_signal_connect_while_alive (GTK_OBJECT (t), "changed",
-					GTK_SIGNAL_FUNC (value_changed), ppc,
+					G_CALLBACK (value_changed), ppc,
 					GTK_OBJECT (ppc->pix_entry));
 	gtk_box_pack_start (GTK_BOX (box), ppc->pix_entry, FALSE, FALSE, 0);
-
+	
 	gtk_entry_set_text (GTK_ENTRY (t),
 			    sure_string (ppc->back_pixmap));
 	
@@ -1677,30 +1691,27 @@ background_page (PerPanelConfig *ppc)
 				      ppc->strech_pixmap_bg);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (fit),
 				      ppc->fit_pixmap_bg);
-	gtk_signal_connect (GTK_OBJECT (fit), "toggled",
-			    GTK_SIGNAL_FUNC (set_fit_pixmap_bg), ppc);
-	gtk_signal_connect (GTK_OBJECT (strech), "toggled",
-			    GTK_SIGNAL_FUNC (set_strech_pixmap_bg), ppc);
+	g_signal_connect (G_OBJECT (fit), "toggled",
+			  G_CALLBACK (set_fit_pixmap_bg), ppc);
+	g_signal_connect (G_OBJECT (strech), "toggled",
+			  G_CALLBACK (set_strech_pixmap_bg), ppc);
 
 	w = gtk_check_button_new_with_label (_("Rotate image for vertical panels"));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 				      ppc->rotate_pixmap_bg);
-	gtk_signal_connect (GTK_OBJECT (w), "toggled",
-			    GTK_SIGNAL_FUNC (set_rotate_pixmap_bg), ppc);
+	g_signal_connect (G_OBJECT (w), "toggled",
+			  G_CALLBACK (set_rotate_pixmap_bg), ppc);
 	gtk_box_pack_start (GTK_BOX (box), w, FALSE, FALSE,0);
 
-	gtk_signal_connect (GTK_OBJECT (ppc->non), "activate", 
-			    GTK_SIGNAL_FUNC (set_back), 
-			    GINT_TO_POINTER(PANEL_BACK_NONE));
-	gtk_signal_connect (GTK_OBJECT (ppc->pix), "activate", 
-			    GTK_SIGNAL_FUNC (set_back), 
-			    GINT_TO_POINTER(PANEL_BACK_PIXMAP));
-	gtk_signal_connect (GTK_OBJECT (ppc->trans), "activate", 
-			    GTK_SIGNAL_FUNC (set_back), 
-			    GINT_TO_POINTER(PANEL_BACK_TRANSLUCENT));
-	gtk_signal_connect (GTK_OBJECT (ppc->col), "activate", 
-			    GTK_SIGNAL_FUNC (set_back), 
-			    GINT_TO_POINTER(PANEL_BACK_COLOR));
+	g_signal_connect (G_OBJECT (ppc->non), "activate", 
+			  G_CALLBACK (set_back), 
+			  GINT_TO_POINTER(PANEL_BACK_NONE));
+	g_signal_connect (G_OBJECT (ppc->pix), "activate", 
+			  G_CALLBACK (set_back), 
+			  GINT_TO_POINTER(PANEL_BACK_PIXMAP));
+	g_signal_connect (G_OBJECT (ppc->col), "activate", 
+			  G_CALLBACK (set_back), 
+			  GINT_TO_POINTER(PANEL_BACK_COLOR));
 	
 	if(ppc->back_type == PANEL_BACK_NONE) {
 		gtk_option_menu_set_history(GTK_OPTION_MENU(ppc->back_om), 0);
@@ -1708,12 +1719,9 @@ background_page (PerPanelConfig *ppc)
 	} else if(ppc->back_type == PANEL_BACK_COLOR) {
 		gtk_option_menu_set_history(GTK_OPTION_MENU(ppc->back_om), 1);
 		gtk_menu_item_activate(GTK_MENU_ITEM(ppc->col));
-	} else if(ppc->back_type == PANEL_BACK_PIXMAP) {
+	} else {
 		gtk_option_menu_set_history(GTK_OPTION_MENU(ppc->back_om), 2);
 		gtk_menu_item_activate(GTK_MENU_ITEM(ppc->pix));
-	} else { /* ppc->back_type == PANEL_BACK_TRANSLUCENT */
-		gtk_option_menu_set_history(GTK_OPTION_MENU(ppc->back_om), 3);
-		gtk_menu_item_activate(GTK_MENU_ITEM(ppc->trans));
 	}
 
 	return vbox;
@@ -1722,17 +1730,17 @@ background_page (PerPanelConfig *ppc)
 static void
 setup_pertype_defs (BasePWidget *basep, PerPanelConfig *ppc)
 {
-	if (IS_BORDER_WIDGET (basep))
+	if (BORDER_IS_WIDGET (basep))
 		ppc->edge = BORDER_POS (basep->pos)->edge;
 	
-	if (IS_ALIGNED_WIDGET(basep)) {
+	if (ALIGNED_IS_WIDGET(basep)) {
 		ppc->align = ALIGNED_POS (basep->pos)->align;
-	} else if (IS_FLOATING_WIDGET (basep)) {
+	} else if (FLOATING_IS_WIDGET (basep)) {
 		FloatingPos *pos = FLOATING_POS (basep->pos);
 		ppc->x = pos->x;
 		ppc->y = pos->y;
 		ppc->orient = PANEL_WIDGET(basep->panel)->orient;
-	} else if (IS_SLIDING_WIDGET(basep)) {
+	} else if (SLIDING_IS_WIDGET(basep)) {
 		SlidingPos *pos = SLIDING_POS (basep->pos);
 		ppc->offset = pos->offset;
 		ppc->align = pos->anchor;
@@ -1763,25 +1771,25 @@ update_config_type (BasePWidget *w)
 
 	setup_pertype_defs (BASEP_WIDGET(w), ppc);
 
-	if(IS_EDGE_WIDGET(w)) {
+	if(EDGE_IS_WIDGET(w)) {
 		/* edge notebook page */
 		page = edge_notebook_page(ppc);
 		gtk_label_set(GTK_LABEL(ppc->type_tab_label),
 			      _("Edge panel"));
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
-	} else if(IS_ALIGNED_WIDGET(w)) {
+	} else if(ALIGNED_IS_WIDGET(w)) {
 		/* aligned notebook page */
 		page = aligned_notebook_page(ppc);
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
 		gtk_label_set(GTK_LABEL(ppc->type_tab_label),
 			      _("Aligned panel"));
-	} else if(IS_SLIDING_WIDGET(w)) {
+	} else if(SLIDING_IS_WIDGET(w)) {
 		/* sliding notebook page */
 		page = sliding_notebook_page(ppc);
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
 		gtk_label_set(GTK_LABEL(ppc->type_tab_label),
 			      _("Sliding panel"));
-	} else if(IS_FLOATING_WIDGET(w)) {
+	} else if(FLOATING_IS_WIDGET(w)) {
 		/* floating notebook page */
 		page = floating_notebook_page(ppc);
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
@@ -1793,22 +1801,23 @@ update_config_type (BasePWidget *w)
 }
 
 static void
-window_clicked (GtkWidget *w, int button, gpointer data)
+window_response (GtkWidget *w, int response, gpointer data)
 {
 	GtkWidget *notebook = data;
-	char *help_path = gtk_object_get_data (GTK_OBJECT (w), "help_path");
+	const char *help_path = gtk_object_get_data (GTK_OBJECT (w), "help_path");
+	const char *help_linkid = gtk_object_get_data (GTK_OBJECT (w), "help_linkid");
 
-	if (button == 1) { /* help */
+	if (response == HELP_BUTTON) {
 		int tab;
 
 		tab = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
 
 		if (tab == 1)
-			panel_show_help ("panelproperties.html#PANELBACKTAB");
+			panel_show_help ("panelproperties", "PANELBACKTAB");
 		else
-			panel_show_help (help_path);
+			panel_show_help (help_path, help_linkid);
 	} else {
-		gnome_dialog_close (GNOME_DIALOG (w));
+		gtk_widget_destroy (w);
 	}
 }
 	     
@@ -1821,6 +1830,7 @@ panel_config (GtkWidget *panel)
 	BasePWidget *basep = BASEP_WIDGET (panel);
 	PanelWidget *pw = PANEL_WIDGET (basep->panel);
 	char *help_path = "";
+	char *help_linkid = NULL;
 	ppc = get_config_struct(panel);
 	
 	/* return if the window is already up. */
@@ -1859,31 +1869,34 @@ panel_config (GtkWidget *panel)
 	ppc->panel = panel;
 	
 	/* main window */
-	ppc->config_window = gnome_dialog_new (_("Panel properties"),
-					       GNOME_STOCK_BUTTON_CLOSE,
-					       GNOME_STOCK_BUTTON_HELP,
-					       NULL);
-	gnome_dialog_set_close (GNOME_DIALOG (ppc->config_window),
-				FALSE /* click_closes */);
-	gtk_window_set_wmclass (GTK_WINDOW(ppc->config_window),
+	ppc->config_window = gtk_dialog_new_with_buttons (_("Panel properties"),
+							  NULL, 0,
+							  GTK_STOCK_CLOSE,
+							  CLOSE_BUTTON,
+							  GTK_STOCK_HELP,
+							  HELP_BUTTON,
+							  NULL);
+	gtk_window_set_wmclass (GTK_WINDOW (ppc->config_window),
 				"panel_properties", "Panel");
 	gtk_widget_set_events (ppc->config_window,
 			       gtk_widget_get_events (ppc->config_window) |
 			       GDK_BUTTON_PRESS_MASK);
 	/*gtk_window_set_position(GTK_WINDOW(ppc->config_window), GTK_WIN_POS_CENTER);*/
-	gtk_window_set_policy(GTK_WINDOW(ppc->config_window), FALSE, FALSE, TRUE);
+	gtk_window_set_policy (GTK_WINDOW (ppc->config_window),
+			       FALSE, FALSE, TRUE);
 
-	gtk_signal_connect(GTK_OBJECT(ppc->config_window), "destroy",
-			   GTK_SIGNAL_FUNC (config_destroy), ppc);
+	g_signal_connect (G_OBJECT (ppc->config_window), "destroy",
+			  G_CALLBACK (config_destroy), ppc);
 	
 	prop_nbook = gtk_notebook_new ();
 
-	gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (ppc->config_window)->vbox),
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (ppc->config_window)->vbox),
 			    prop_nbook, TRUE, TRUE, 0);
 
-	if(IS_EDGE_WIDGET(panel)) {
+	if(EDGE_IS_WIDGET(panel)) {
 		/* edge notebook page */
-		help_path = "panelproperties.html#EDGETAB";
+		help_path = "panelproperties";
+		help_linkid = "EDGETAB";
 		page = edge_notebook_page(ppc);
 		ppc->type_tab = gtk_event_box_new();
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
@@ -1891,9 +1904,10 @@ panel_config (GtkWidget *panel)
 		gtk_notebook_append_page(GTK_NOTEBOOK(prop_nbook),
 					 ppc->type_tab,
 					 ppc->type_tab_label);
-	} else if(IS_ALIGNED_WIDGET(panel)) {
+	} else if(ALIGNED_IS_WIDGET(panel)) {
 		/* aligned notebook page */
-		help_path = "panelproperties.html#EDGETAB";
+		help_path = "panelproperties";
+		help_linkid = "EDGETAB";
 		page = aligned_notebook_page(ppc);
 		ppc->type_tab = gtk_event_box_new();
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
@@ -1901,9 +1915,10 @@ panel_config (GtkWidget *panel)
 		gtk_notebook_append_page(GTK_NOTEBOOK(prop_nbook),
 					 ppc->type_tab,
 					 ppc->type_tab_label);
-	} else if(IS_SLIDING_WIDGET(panel)) {
+	} else if(SLIDING_IS_WIDGET(panel)) {
 		/* sliding notebook page */
-		help_path = "panelproperties.html#EDGETAB";
+		help_path = "panelproperties";
+		help_linkid = "EDGETAB";
 		page = sliding_notebook_page(ppc);
 		ppc->type_tab = gtk_event_box_new();
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
@@ -1911,9 +1926,10 @@ panel_config (GtkWidget *panel)
 		gtk_notebook_append_page(GTK_NOTEBOOK (prop_nbook),
 					 ppc->type_tab,
 					 ppc->type_tab_label);
-	} else if(IS_FLOATING_WIDGET(panel)) {
+	} else if(FLOATING_IS_WIDGET(panel)) {
 		/* floating notebook page */
-		help_path = "panelproperties.html#EDGETAB";
+		help_path = "panelproperties";
+		help_linkid = "EDGETAB";
 		page = floating_notebook_page(ppc);
 		ppc->type_tab = gtk_event_box_new();
 		gtk_container_add(GTK_CONTAINER(ppc->type_tab), page);
@@ -1921,13 +1937,14 @@ panel_config (GtkWidget *panel)
 		gtk_notebook_append_page(GTK_NOTEBOOK (prop_nbook),
 					 ppc->type_tab,
 					 ppc->type_tab_label);
-	} else if(IS_DRAWER_WIDGET(panel)) {
+	} else if(DRAWER_IS_WIDGET(panel)) {
 		BasePWidget *basep = BASEP_WIDGET(panel);
 		GtkWidget *applet = PANEL_WIDGET(basep->panel)->master_widget;
 		AppletInfo *info =
 			gtk_object_get_data(GTK_OBJECT(applet), "applet_info");
 		add_drawer_properties_page(ppc, GTK_NOTEBOOK (prop_nbook), info->data);
-		help_path = "drawers.html";
+		help_path = "drawers";
+		help_linkid = NULL;
 		/* we can't change to/from drawers anyhow */
 		ppc->type_tab = NULL;
  	}
@@ -1939,13 +1956,15 @@ panel_config (GtkWidget *panel)
 
 	gtk_object_set_data (GTK_OBJECT (ppc->config_window), "help_path",
 			     help_path);
-	gtk_signal_connect (GTK_OBJECT (ppc->config_window), "clicked",
-			    GTK_SIGNAL_FUNC (window_clicked),
-			    prop_nbook);
+	gtk_object_set_data (GTK_OBJECT (ppc->config_window), "help_linkid",
+			     help_linkid);
+	g_signal_connect (G_OBJECT (ppc->config_window), "response",
+			  G_CALLBACK (window_response),
+			  prop_nbook);
 	
-	gtk_signal_connect (GTK_OBJECT (ppc->config_window), "event",
-			    GTK_SIGNAL_FUNC (config_event),
-			    prop_nbook);
+	g_signal_connect (G_OBJECT (ppc->config_window), "event",
+			  G_CALLBACK (config_event),
+			  prop_nbook);
 	
 	ppc->register_changes = TRUE;
 
